class BlockPickingsController < ApplicationController
  def self.set_target_before
    super + [:search]
  end

  model_data_store(BlockPicking)

  def create
    shift_references = shift_reference_params
    return render json: {error: "The selected shifts do not exist"}, status: :unprocessable_entity unless ShiftHandler.shifts_exists?(shift_references)

    @model = model_type.new(model_params)
    @model.shift_references << shift_references.map do |shift_id|
      ShiftReference.find_or_create_by(hub_shift_id: shift_id)
    end
    if @model.save
      render json: @model, status: :created, location: @model
    else
      render json: @model.errors, status: :unprocessable_entity
    end
  end

  def update
    shift_references = shift_reference_params
    return render json: {error: "The selected shifts do not exist"}, status: :unprocessable_entity unless ShiftHandler.shifts_exists?(shift_references)

    @model.block_picking_shift_references.destroy_all

    @model.shift_references << shift_references.map do |shift_id|
      ShiftReference.find_or_create_by(hub_shift_id: shift_id)
    end

    if @model.update(model_params)
      render json: @model, status: :ok, location: @model
    else
      render json: @model.errors, status: :unprocessable_entity
    end
  end

  def search
    job_num = search_params

    block_info = @model.get_block_info(job_num)

    if block_info.error
      if block_info.error[:jobDoesNotExist]
        render status: :not_found, json: {error: "Unable to find data for job #{job_num}."}
      else
        render status: :internal_server_error, json: {error: block_info.error[:message]}
      end
    else
      render status: :ok, json: block_info.data
    end
  end

  private
  # Only allow a list of trusted parameters through.
  def model_params
    params.require(:block_picking).permit(:name,
                                          :hide_tray_number,
                                          :hide_block_count,
                                          :use_scan_count,
                                          :send_job_states,
                                          :hide_job_number,
                                          :external_dcs_id)
  end

  def shift_reference_params
    params.require(:block_picking).fetch(:hub_shift_ids)
  end

  def search_params
    params.require(:tray_number)
  end
end
