class MachineDataPushTargetsController < ApplicationController
  def self.set_target_before
    super + [:add_machines]
  end

  model_data_store(MachineDataPushTarget)

  def create
    @model = MachineDataPushTarget.new(__mssql_model_params__.except(:id, :machine_data_push_target_headers))

    handle_new_headers

    if @model.save
      render json: @model
    else
      render json: @model.errors, status: :unprocessable_entity
    end
  end

  def update
    @model.assign_attributes(__mssql_model_params__.except(:id, :machine_data_push_target_headers))

    handle_new_headers

    if @model.save
      render json: @model, status: :ok, location: @model
    else
      render json: @model.errors.full_messages, status: :unprocessable_entity
    end
  end

  def add_machines
    machines = Machine.where(id: add_machines_params[:machine_ids])
    if @model.machines << machines
      render json: @model
    else
      render json: @model.errors, status: :unprocessable_entity
    end
  end

  private

  def add_machines_params
    params.require(:machine_data_push_target).permit(:machine_ids => [])
  end

  # Only allow a list of trusted parameters through.
  def model_params
    params.require(:machine_data_push_target).permit(:name,
                                                     :base_url,
                                                     :order_path,
                                                     :update_order_path,
                                                     :machine_state_path,
                                                     :job_state_path,
                                                     :error_path,
                                                     :event_path,
                                                     :maintenance_path,
                                                     :calibration_path,
                                                     :process_data_path,
                                                     :order_method,
                                                     :update_order_method,
                                                     :machine_state_method,
                                                     :job_state_method,
                                                     :error_method,
                                                     :event_method,
                                                     :maintenance_method,
                                                     :calibration_method,
                                                     :process_data_method,
                                                     :send_to,
                                                     :include_request_params,
                                                     :include_machine_name
    )
  end

  def new_headers_params
    params.require(:machine_data_push_target).permit(machine_data_push_target_headers: [:header, :value, :machine_data_push_target_id])
  end

  def handle_new_headers
    new_header_params = new_headers_params[:machine_data_push_target_headers]

    new_header_params.each do |header|
      @model.machine_data_push_target_headers.build(header)
    end
  end
end
