class MachineStatesController < ApplicationController
  include MachineResponse
  include MachineDataViewFilter
  include RxModule::Tableable

  wrap_parameters :machine_state, include: [:sn, :date, :time, :state, :comment, :addon]
  model_data_store(MachineState)

  # PUT /machinestate/2.0/add
  def add
    begin
      AddMachineStateJob.perform_later(model_params)
    rescue => e
      Rails.logger.error e
    end
    send_machine_response
  end

  def before_set_targets
    models = if filters["sn"]
      MachineState.where(machine_sn: filters["sn"])
    else
      MachineState
    end
    view_before_set_targets(models, params)
  end

  def before_filter(filter)
    view_before_filter(filter)
  end

  private

  # Never trust parameters from the scary internet, only allow the white list through.
  def model_params
    params[:machine_state] = params[:machinestate] if params[:machinestate]
    machine_state = params.require(:machine_state)
    {
      state: enum_value(machine_state[:state]),
      time: "#{params[:date]} #{params[:time]}",
      machine_sn: params[:sn],
      comment: machine_state[:comment],
      addon: machine_state[:addon]
    }
  end
end
