class MaintenancesController < ApplicationController
  include MachineResponse
  include MachineDataViewFilter
  include RxModule::Tableable

  wrap_parameters :maintenance_model, include: [:maintenance, :type, :status, :date, :time, :sn]
  model_data_store(Maintenance)

  def add
    begin
      AddMaintenanceJob.perform_later(model_params)
    rescue => e
      Rails.logger.error e
    end
    send_machine_response
  end

  def before_set_targets
    models = if filters["sn"]
      Maintenance.where(machine_sn: filters["sn"])
    else
      Maintenance
    end
    view_before_set_targets(models, params)
  end

  def before_filter(filter)
    view_before_filter(filter)
  end

  private

  # Never trust parameters from the scary internet, only allow the white list through.
  def model_params
    params[:maintenance_model] = params[:maintenance] if params[:maintenance].is_a?(ActionController::Parameters)
    maintenance = params.require(:maintenance_model)
    {
      maintenance: maintenance[:maintenance],
      maintenance_type: enum_value(maintenance[:type]),
      status: enum_value(maintenance[:status]),
      time: "#{params[:date]} #{params[:time]}",
      machine_sn: params[:sn]
    }
  end
end
