class ProcessBookingWorkstationsController < ApplicationController
  include DataHelpers

  def self.set_target_before
    super + [:book]
  end

  model_data_store(ProcessBookingWorkstation)

  def book
    params = book_job_params

    machine_sn = params[:machine_sn]
    job_num = params[:job_number]

    machine = Machine.find_by_sn(machine_sn)
    return render json: {error: "No machine with SN #{machine_sn}."}, status: :unprocessable_entity if machine.nil?

    job = FindHelpers::JobFinders.active_with_number(job_num)
    return render json: {error: "No job with number #{job_num}."}, status: :unprocessable_entity if job.nil?

    return render json: {error: "Job not attached to order"}, status: :unprocessable_entity if job.order.nil?

    other_side = job.opposite_job

    post_job_state(machine_sn, job.number, job.side_letter, JobStates::FINISHED, 'manual_booked')
    #Cant send the process finished back to back otherwise things like routing auto start won't work correctly.
    post_job_state(machine_sn, other_side.number, other_side.side_letter, JobStates::FINISHED, 'manual_booked', wait: 15.seconds) if other_side

    render json: {status: 'ok'}, status: :ok
  end

  private


  def model_params
    params.require(:process_booking_workstation).permit(:name, machine_ids: [])
  end

  def book_job_params
    params.permit(:job_number, :machine_sn)
  end
end
