module MachineDashboardHelpers
  include MachineConcern
  extend ActiveSupport::Concern
  included do
    def buckets
      return self.class.total_time[0][:value] if @parameters[:buckets].blank?
      @parameters[:buckets]
    end

    def offset
      @parameters[:offset]
    end

    def start_and_end_time
      now_time = Time.zone.now
      total_seconds = (buckets.to_i - 1).hours
      s_time = now_time.advance(seconds: -1 * total_seconds).beginning_of_hour
      e_time = now_time.end_of_hour
      if offset
        if now_time.strftime("%M").to_i < 30
          s_time = s_time.advance(minutes: -30)
          e_time = e_time.advance(minutes: -30)
        else
          s_time = s_time.advance(minutes: 30)
          e_time = e_time.advance(minutes: 30)
        end
      end
      [s_time, e_time]
    end

    class << self
      def run_in_background?
        true
      end

      def machine_performance_setup(type_override: nil, target_type: nil, options_override: nil)
        ui_hint(type: 'type_override')
        ui_hint(type_override: type_override)
        ui_hint(options_override: options_override)
        targets("Machine", "The machine(s) to track", -> { machine_targets }, target_type: target_type, custom_targets: false)
        parameter(:buckets, "Hours to display", "How many hours to display", :string, required: true, value_list: -> { total_time })
        parameter(:offset, "Start at mid-hour?", "When enabled, column starts with start at the middle of the hour (ex: 1:30, 2:30, etc.)", :boolean, default: false)
      end

      def machine_targets
        MachineGroup.all.map do |g|
          {
            label: MachineDashboardHelpers.target_to_name(g),
            value: MachineDashboardHelpers.target_to_id(g),
            values_in_group: g.machines.map {|m| MachineDashboardHelpers.target_to_id(m)},
            group: "Machine Group",
            description: "Report on performance for the entire #{g.name} group"
          }
        end + Machine.all.map do |m|
          {
            label: MachineDashboardHelpers.target_to_name(m),
            value: MachineDashboardHelpers.target_to_id(m),
            group: "Machine",
            description: "Report on performance for machine #{m.name}, sn #{m.sn}"
          }
        end
      end

      def total_time
        [
          {
            label: '8',
            value: '8',
            description: 'Display 8 hours of machine data'
          },
          {
            label: '12',
            value: '12',
            description: 'Display 12 hours of machine data'
          }
        ]
      end

      def color_for_state(state)
        color = colors.find{|c| c[0].downcase == state.to_s.downcase }
        if color.nil?
          '#ABB2B9'
        else
          color[1]
        end
      end

      def colors
        return @colors unless @colors.nil?
        @colors = Color.all.pluck(:status_name, :color)
        @colors
      end

      def states_in_order
        grouped_states_in_order.flatten
      end

      def grouped_states_in_order
        [
          [:processing],
          [:waitingforjobs],
          [:estop, :halt, :notready, :error],
          [:maintenance, :on, :setup, :ready],
          [:off]
        ]
      end

      def find_state_group_for_state(state)
        state_group = nil
        grouped_states_in_order.each do |group|
          state_group = group unless group.find {|s| s == state}.nil?
        end
        state_group
      end

      def group_state_id(state)
        {
          :processing => "processing",
          :waitingforjobs => "waitingforjobs",
          :estop => "stoppage",
          :halt => "stoppage",
          :notready => "stoppage",
          :error => "stoppage",
          :maintenance => "online",
          :on => "online",
          :setup => "online",
          :ready => "online",
          :off => "offline"
        }[state]
      end
    end
  end
end
