class MachineStatePieDashboard < RxModule::Dashboards::CategoryChart
  include MachineDashboardHelpers
  include DataHelpers
  include KpiHelpers

  expose('machine_state_pie', 'Machine State Pie', 'View the percentage of time spent in each machine state for the selected machine')
  machine_performance_setup(type_override: 'pie', target_type: 'series', options_override: {
    legend: {
      position: 'right'
    },
    dataLabels: {
      enabled: true,
      formatter: 'machine_state_pie'
    }
  })
  yunit('%')

  def build_results!
    setup_targets!

    machine_ids = machines.pluck(:id)
    start_time, end_time = start_and_end_time

    @_machine_states = MachineKpi.state_breakdown_between(start_time,
                                                        end_time,
                                                        Timeframe::ALL,
                                                        machine_ids,
                                                        options: { addons: [:as_percent] })
    if ProductionSetting.use_simple_machine_state_colors?
      build_simplified_dashboard_series
    else
      build_dashboard_series
    end
  end

  def machines
    @_machines ||= []
  end

  def setup_targets!
    ids = []
    targets.each do |id|
      category, ref = id.split("-")
      case category
      when 'm'
        ids << ref.to_i
      when 'g'
        g = MachineGroup.find(ref)
        g.machine_ids.each {|m_id| ids << m_id } unless g.nil?
      end
    end
    ids = ids.uniq # could be duplicates between machine and group
    @_machines = Machine.where(id: ids).find_each.to_a
  end

  def build_simplified_dashboard_series
    push_series("machine_states", "machine_state")

    self.class.grouped_states_in_order.each do |group|
      value = value_for_machine_state_group(group, @_machine_states)
      next unless value[:percent] > 0
      push_point("machine_states", value[:percent], group.join(", "), self.class.color_for_state(group[0]))
    end
  end

  def build_dashboard_series
    push_series("machine_states", "machine_state")
    self.class.states_in_order.map do |state|
      value = @_machine_states[state]
      next unless value[:percent] > 0
      push_point("machine_states", value[:percent], state, self.class.color_for_state(state))
    end
  end
end