import * as React from 'react';
import {makeColumn, ModelTable} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {createStyles, IconButton, Theme} from "@material-ui/core";
import {observer} from "mobx-react-lite";
import {ColorPicker} from "material-ui-color";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faPen} from "@rx-suite/pro-solid-svg-icons";
import {MachineStore} from "../../../stores/MachineStore";
import {MachineGroupModel, MachineGroupStore} from "../../../stores/MachineGroupStore";
import {StatusColorModel, StatusColorStore} from "../../../stores/StatusColorStore";
import {useSnackbar} from "notistack";
import {makeStyles} from "@material-ui/core/styles";
import {MachineGroupColorEditDialog} from "./MachineGroupColorEditDialog";

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        button: {
            padding: theme.spacing(1)
        }
    })
);

export const MachineGroupColorTab = observer(() => {
    const classes = useStyles();
    const {enqueueSnackbar} = useSnackbar();

    const machines = MachineStore.getAll();

    const [dialogOpen, setDialogOpen] = React.useState(false);
    const [selectedStatusColor, setSelectedStatusColor] = React.useState<StatusColorModel>(StatusColorStore.createModel());

    const handleSubmit = React.useCallback((submitModel: StatusColorModel) => {
        submitModel.viewModel.submit();
        submitModel.commit().then(function(resp:any){
            enqueueSnackbar(`${t`Group successfully updated!`}`, {variant: "success"});
            setDialogOpen(false);
        });
        setDialogOpen(false);
    }, [selectedStatusColor]);

    const handleClickOpen = React.useCallback((colorModel: StatusColorModel) => {
        setSelectedStatusColor(colorModel);
        setDialogOpen(true);
    }, []);

    const handleClose = () => {
        setDialogOpen(false);
    }

    const columns = React.useMemo(() => {
        return [
            makeColumn('name', t`Group Name`, "string"),
            {
                Header: t`Group Color`,
                id: 'color',
                accessor: (model: MachineGroupModel) => model,
                Cell: (cellInfo: {value: MachineGroupModel }) => {
                    const model = cellInfo.value as MachineGroupModel;

                    if(!model.color){
                        return null;
                    }

                    return (
                        <ColorPicker value={cellInfo.value.color}  disableAlpha hideTextfield onChange={()=>null}/>
                    )
                },
                filterable: false,
                sortable: false,
            }
        ];
    }, [machines]);

    return(
        <React.Fragment>
            <ModelTable store={MachineGroupStore}
                        columns={columns}
                        showCreateButton={false}
                        replacementActions={
                            {
                                Edit: ({model}) =>
                                    <IconButton onClick={() => handleClickOpen(model as StatusColorModel)} size={"small"} className={classes.button}>
                                        <FontAwesomeIcon icon={faPen}/>
                                    </IconButton>,
                                Delete: () => null,
                                Read: () => null
                            }
                        }
                        suppressWrapper
                        noLinkColumns={['name', 'color']}
            />
            <MachineGroupColorEditDialog model={selectedStatusColor} open={dialogOpen} handleClose={handleClose} handleSubmit={handleSubmit}/>
        </React.Fragment>
    )
});
