import * as React from "react";
import {observer} from "mobx-react-lite";
import {ModelInput, ModelSelect} from "@rx-suite/ui";
import {Grid, makeStyles, Typography} from "@material-ui/core";
import {t} from "@lingui/macro";

type ExternalForwardingEndpointsTabProps = {
    hideMachineData: boolean;
}

const useStyles = makeStyles(() => ({
    selectField: {
        height: '56.25px'
    }
}));

export  const ExternalForwardingEndpointsTab: React.FunctionComponent<ExternalForwardingEndpointsTabProps> = observer(({hideMachineData}) => {
    const classes = useStyles();
    const methodOptions = [
        { label: "PUT", value: "put"},
        { label: "POST", value: "post"}
    ]

    if (hideMachineData) {
        return (
            <React.Fragment>
                <Grid container spacing={2}>
                    <Grid item xs={2}>
                        <Typography variant={'h5'}>{t`Method`}</Typography>
                        <ModelSelect name={'order_method'} options={methodOptions} className={classes.selectField} />
                        <ModelSelect name={'update_order_method'} options={methodOptions} className={classes.selectField} />
                    </Grid>
                    <Grid item xs={10}>
                        <Typography variant={'h5'}>{t`Path`}</Typography>
                        <ModelInput name={'order_path'} />
                        <ModelInput name={'update_order_path'} />
                    </Grid>
                </Grid>
            </React.Fragment>
        );
    }

    return (
        <React.Fragment>
            <Grid container spacing={2}>
                <Grid item xs={2}>
                    <Typography variant={'h5'}>{t`Method`}</Typography>
                    <ModelSelect name={'machine_state_method'} options={methodOptions} className={classes.selectField} />
                    <ModelSelect name={'job_state_method'} options={methodOptions} className={classes.selectField} />
                    <ModelSelect name={'error_method'} options={methodOptions} className={classes.selectField} />
                    <ModelSelect name={'event_method'} options={methodOptions} className={classes.selectField} />
                    <ModelSelect name={'maintenance_method'} options={methodOptions} className={classes.selectField} />
                    <ModelSelect name={'calibration_method'} options={methodOptions} className={classes.selectField} />
                    <ModelSelect name={'process_data_method'} options={methodOptions} className={classes.selectField} />
                </Grid>
                <Grid item xs={10}>
                    <Typography variant={'h5'}>{t`Path`}</Typography>
                    <ModelInput name={'machine_state_path'} />
                    <ModelInput name={'job_state_path'} />
                    <ModelInput name={'error_path'} />
                    <ModelInput name={'event_path'} />
                    <ModelInput name={'maintenance_path'} />
                    <ModelInput name={'calibration_path'} />
                    <ModelInput name={'process_data_path'} />
                </Grid>
            </Grid>
        </React.Fragment>
    );
})
