import * as React from "react";
import {observer} from "mobx-react-lite";
import {ExternalForwardingHeadersForm} from "./ExternalForwardingHeadersForm";
import {AssociatedModelTable, makeColumn} from "@rx-suite/ui";
import {MachineDataPushTargetHeaderStore} from "../../stores/MachineDataPushTargetHeaderStore";
import {t} from "@lingui/macro";
import {MachineDataPushTargetModel} from "../../stores/MachineDataPushTargetStore";

type ExternalForwardingHeadersTabProps = {
    model: MachineDataPushTargetModel
}

export const ExternalForwardingHeadersTab: React.FunctionComponent<ExternalForwardingHeadersTabProps> = observer(({model}) => {
    const columns = React.useMemo(() => {
        return [
            makeColumn("header", t`Header`, "string"),
            makeColumn("value", t`Value`, "string")
        ]
    }, [])

    return (
        <AssociatedModelTable
            baseModel={model}
            associatedColumnName={'machine_data_push_target_headers'}
            store={MachineDataPushTargetHeaderStore}
            columns={columns}
            fixedHeight={false}
            DialogForm={ExternalForwardingHeadersForm}
            dialogTitle={t`Add Headers`}
            defaultFiltered={[{ id: 'machine_data_push_target_id', value: model.getId() }]}
            replacementActions={
                {
                    Read: () => null
                }
            }
            noLinkColumns={['header', 'value']}
            suppressWrapper
            createButtonText={t`Add Header`}
        />
    )
})