import * as React from "react";
import {createStyles, Divider, Grid, List, makeStyles, Switch, Theme} from "@material-ui/core";
import {ErrorFilterModel} from "../../stores/ErrorFilterStore";
import {t} from "@lingui/macro";
import {useSnackbar} from "notistack";
import {observer} from "mobx-react-lite";
import {AbortFilterModel} from "../../stores/AbortFilterStore";

type ToggleFilterSwitchProps = {
    model: ErrorFilterModel | AbortFilterModel
};

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        switch: {
            "& .MuiIconButton-root" : {
                padding: '9px',
            }
        }
    })
);

// TODO: make this generic for model with a enabled property
export const ToggleFilterSwitch: React.FunctionComponent<ToggleFilterSwitchProps> = observer(({model}) => {
    const {enqueueSnackbar} = useSnackbar();
    const classes = useStyles();

    const handleChange = React.useCallback( async () => {
        const resp = await model.toggle();
        if(resp.status === 200) {
            enqueueSnackbar(t`Filter successfully updated.`, {variant: "success"});
        } else {
            enqueueSnackbar(t`Failed to update filter.`, {variant: "error"});
        }
    }, [model])

    return (
        <Switch className={classes.switch} checked={model.enabled} color={'secondary'} onChange={handleChange}/>
    );
});