import * as React from "react";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {MachineDataViewTab} from "../MachineDataViewTab";
import {JobStateModel, JobStateStore} from "../../../stores/JobStateStore";
import {JobModel} from "../../../stores/JobStore";
import {makeColumn, makeFormattedDateTimeColumn, SelectField} from "@rx-suite/ui";
import {Filter, ReactTableFunction} from "react-table";
import {MachineDataViewPanelProps} from "../MachineDataView";
import {useJobSideColumn} from "../../../hooks/table_columns/useJobSideColumn";


export const JobStatesPanel: React.FunctionComponent<MachineDataViewPanelProps> = observer((props) => {
    const {machine} = props;
    const store = JobStateStore

    const columns = [
        {Header: t`Job States`, columns: [
                {
                    Header: t`Job Number`,
                    id: 'job_number',
                    filterable: true,
                    accessor: (jobState: JobStateModel) => {
                        const job = jobState.job as JobModel;

                        if(!job){
                            return 'n/a';
                        }
                        return job.number;
                    }
                },
                useJobSideColumn(machine, `side`),
                {
                    Header: t`State`,
                    id: 'state',
                    accessor: 'state',
                    filterable: true,
                    Filter: ({ filter, onChange }: { filter: Filter, onChange: ReactTableFunction}) => (
                        <SelectField
                            options={
                                [
                                    {label: t`started`, value: 3},
                                    {label: t`aborted`, value: 4},
                                    {label: t`finished`, value: 5},
                                    {label: t`postponed`, value: 6},
                                    {label: t`skipped`, value: 7},
                                    {label: t`restarted`, value: 8},
                                    {label: t`all`, value: ""}
                                ]
                            }
                            onChange={(name, value) => onChange(value)}
                            value={filter ? filter.value : ""}
                        />
                    )
                },
                makeColumn('substate', t`Substate`, "string"),
                {
                    Header: t`Scrap`,
                    id: 'scrap',
                    accessor: (jobState: JobStateModel) => {
                        if(jobState.scrap === null){
                            return '';
                        }

                        return  jobState.scrap ? 'T' : 'F'
                    }
                },
                makeColumn('scrap_reason', t`Scrap Reason`, "string"),
                makeColumn('comment', t`Comment`, "string"),
                makeFormattedDateTimeColumn("time", t`Date - Time`, "dateTime")
            ]
        }];

    return (
        <MachineDataViewTab
            columns={columns}
            machine={machine}
            enabledKey={'job_state_enabled'}
            tabName={'Job State'}
            store={store}
            exportedFileName={'JobStates.csv'}
            exportEndpoint={'job_states'}
        />
    );
});
