import * as React from "react";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {MachineDataViewTab} from "../MachineDataViewTab";
import {makeColumn, makeFormattedDateTimeColumn} from "@rx-suite/ui";
import {JobProcessParameterStore} from "../../../stores/JobProcessParameterStore";
import {useJobSideColumn} from "../../../hooks/table_columns/useJobSideColumn";
import {MachineDataViewPanelProps} from "../MachineDataView";

export const ProcessDataPanel: React.FunctionComponent<MachineDataViewPanelProps> = observer((props) => {
    const {machine} = props;
    const store = JobProcessParameterStore;

    const columns = [
        {
            Header: t`Process Data`,
            columns: [
                makeColumn('job_process.job.number', 'Job Number', 'string'),
                useJobSideColumn(machine, `job_process.side`),
                makeColumn('name', 'Tag', 'string'),
                makeColumn('value', 'Value', 'string'),
                makeFormattedDateTimeColumn('job_process.time', 'Date - Time', 'dateTime')
            ]
        }
    ];

    return (
        <MachineDataViewTab
            columns={columns}
            machine={machine}
            enabledKey={'process_data_enabled'}
            tabName={'Process'}
            store={store}
            defaultSorted={[{id: "job_process.time", desc: true}]}
            exportedFileName={'ProcessData.csv'}
            exportEndpoint={'process_data'}
        />
    );
});


