import * as React from "react";
import {observer} from "mobx-react-lite";
import {ScannerField} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {ProcessBookingWorkstationState} from "../../pages/process_booking_workstations/ProcessBookingWorkstation";

type ProcessBookingWorkstationJobSearchFieldProps = {
   jobNumber: string | null;
   setJobNumber: React.Dispatch<React.SetStateAction<string>>;
   workstationState: ProcessBookingWorkstationState;
   setWorkstationState: React.Dispatch<React.SetStateAction<ProcessBookingWorkstationState>>;
}

export const ProcessBookingWorkstationJobSearchField: React.FunctionComponent<ProcessBookingWorkstationJobSearchFieldProps> = observer((props) => {
    const {jobNumber, setJobNumber, workstationState,setWorkstationState, disabled} = props;

    const inputRef = React.useRef<HTMLInputElement>();

    React.useEffect(() => {
        if(workstationState == 'scan_job' && inputRef.current){
            inputRef.current.focus();
        }
    }, [inputRef.current, workstationState]);

    const handleChange = (e: any) => {
        const val = e.target.value;
        setJobNumber(val);
    };

    const onSubmit = (e: any) => {
        setWorkstationState('scan_sn');
    };

    return (
       <>
           <ScannerField
               inputConfig={{
                   label: t`Job Number`,
                   value: jobNumber,
                   onChange: handleChange,
                   disabled: workstationState === 'submitting'
               }}
               scanConfig={{
                   onComplete: onSubmit,
                   onPartial: onSubmit,
                   minLength: 4,
                   averageWaitTime: 20
               }}
               inputRefOverride={inputRef}
               global={false}
           />
       </>
    )
})