import * as React from 'react';
import {observer} from "mobx-react-lite";
import {FormProps, ModelForm, ModelInput} from "@rx-suite/ui";

import {t} from "@lingui/macro";
import {Button, Grid, Typography} from "@material-ui/core";
import {green, grey, red} from "@material-ui/core/colors";
import {makeStyles} from "@material-ui/core/styles";
import {useSnackbar} from "notistack";
import {DataArchiveSettingStore} from "../stores/DataArchiveSettingStore";
import {useCallback} from "react";

const useStyles = makeStyles(() => ({
    expired: {
        fontWeight: "bold",
        color: red[700]
    },
    active: {
        fontWeight: "bold",
        color: green[700]
    },
    archived: {
        fontWeight: "bold",
        orange: grey[700]
    },
    reactivateButton: {
        padding: '2px 8px',
        marginLeft: '8px'
    }
}));

export const JobForm:React.FunctionComponent<FormProps> = observer(({ model, readOnly }) => {
    const classes = useStyles();
    const settings = DataArchiveSettingStore.getAll()[0];

    const {enqueueSnackbar} = useSnackbar();

    const [reviving, setReviving] = React.useState<boolean>(false);

    const handleRevive = useCallback(async () => {
        if(!settings){
            return enqueueSnackbar(`${t`Unable to reactive the job number.`}`, {variant: "error"})
        }
        try {
            setReviving(true);
            await fetch(`/api/jobs/${model.id}/revive`, {
                method: "PATCH",
                headers: {'Content-Type': 'application/json'}
            }).then(resp => resp.json())
            .then(data => {
                if (data.error) throw data.error;

                enqueueSnackbar(t`Job Revived`, {variant: "success"});
            });
        } catch (err) {
            const message = (err === 'jobAlreadyActive'
                ? t`Job number already in use`
                : t`Could not revive Job`
            );
            enqueueSnackbar(message, {variant: "error"});
        } finally {
            setReviving(false);
        }
    }, [model, settings]);

    const stateClass = model.viewModel.status

    return(
    <ModelForm model={model} readOnly={readOnly}>
        <ModelInput name={"number"} />
        <Grid container alignItems="center">
            <Typography>{t`Job Number State: `}</Typography>
            <Typography className={stateClass}>{model.viewModel.status}</Typography>
            {model.viewModel.status === 'expired' && !readOnly && <Button
                className={classes.reactivateButton}
                size="large"
                variant={"contained"}
                color="secondary"
                onClick={handleRevive}
                disableElevation
                disabled={reviving}
            >
                {t`Reactivate`}
            </Button>}
        </Grid>
        <ModelInput name={"name"} />
        <ModelInput name={"description"}/>
        <ModelInput name={"sequence_number"}/>
        <ModelInput name={"priority"}/>
        <ModelInput name={"manufacturer"}/>
        <ModelInput name={"side"}/>
        <ModelInput name={"lmat_id"}/>
        <ModelInput name={"lmat_type"}/>
        <ModelInput name={"batch_criteria"}/>
        <ModelInput name={"template"}/>
        <ModelInput name={"job_type"}/>
        <ModelInput name={"enabled"}/>
    </ModelForm>
    )
});