import * as React from 'react';
import {BreadModel, makeColumn, SelectField} from "@rx-suite/ui";
import {MachineTypeModel, MachineTypeStore} from "../../stores/MachineTypeStore";
import {MachineTypesForm} from "./MachineTypesForm";
import {t} from "@lingui/macro";
import {observer} from "mobx-react-lite";
import {Filter, ReactTableFunction} from "react-table";

export const MachineTypesBreadModel = observer(() => {
    const categorySelectFilter = [
        {label: 'All', value: ''},
        {label: 'Blocker', value: 'blocker'},
        {label: 'Deblocker', value: 'deblocker'},
        {label: 'Generator', value: 'generator'},
        {label: 'Polisher', value: 'polisher'},
        {label: 'Other', value: 'other'}
    ]

    const columns = React.useMemo(() => {
        return [
            makeColumn('display_name', t`Name`, "string"),
            {
                Header: t`Category`,
                accessor: d => d,
                id: 'category',
                Cell: (cellInfo: {value: MachineTypeModel }) => {
                    return cellInfo.value.category;
                },
                filterable: true,
                Filter: ({filter, onChange}: { filter: Filter, onChange: ReactTableFunction }) => (
                    <SelectField
                        options={categorySelectFilter}
                        onChange={(name, value) => onChange(value)}
                        value={filter ? filter.value : ""}
                    />
                ),
            }
        ];
    }, []);

    return(
        <BreadModel
            store={MachineTypeStore}
            Form={MachineTypesForm}
            columns={columns}
            mountCreate={false}
            tableProps={
                {
                    showCreateButton: false,
                    replacementActions: {
                        Delete: () => null,
                        Edit: () => null
                    }
                }
            }
        />
    )
});