import * as React from 'react';
import {FormProps, PaddedPaper} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {ModelProvider} from "@rx-suite/ui/build";
import {Divider, Grid, makeStyles, Typography} from "@material-ui/core";
import {MachineTypeImage} from "../../components/machine/machine_worsktation/MachineTypeImage";
import {MachineTypeModel} from "../../stores/MachineTypeStore";
import {t} from "@lingui/macro";
import {TabsContainer} from "../../components/generic/TabsContainer";
import {MachineTypeErrorFilterList} from "../../components/machine_type/MachineTypeErrorFilterList";
import {MachineTypeAbortFilterList} from "../../components/machine_type/MachineTypeAbortFilterList";

const useStyles = makeStyles(theme => ({
    divider: {
        marginTop: theme.spacing(0.5),
        marginBottom: theme.spacing(0.5)
    }
}));

type MachineTypesFormProps = {
    model: MachineTypeModel
} & Omit<FormProps, 'model'>

export const MachineTypesForm: React.FunctionComponent<MachineTypesFormProps> = observer(({model}) => {
    const classes = useStyles();

    return (
        <PaddedPaper>
            <ModelProvider value={model}>
                <Grid container>
                    <MachineTypeImage type={model as MachineTypeModel}/>
                    <Typography variant={'h3'}>{model.display_name}</Typography>
                </Grid>
                <Divider className={classes.divider}/>
                <TabsContainer
                    variant="scrollable"
                    scrollButtons="auto"
                    tabs={[
                        {
                            label: t`Error Filters`,
                            component: <MachineTypeErrorFilterList machineType={model}/>,
                            defaultTab: true
                        },
                        {
                            label: t`Abort Filters`,
                            component: <MachineTypeAbortFilterList machineType={model}/>,
                            defaultTab: true
                        }
                    ]}
                />
            </ModelProvider>
        </PaddedPaper>
    );
});