import * as React from 'react';
import {observer} from "mobx-react-lite";
import {MachineGroupStore} from "../../../stores/MachineGroupStore";
import {MachineDataView} from "../../../components/machine_data/MachineDataView";
import {Divider, Grid, makeStyles, Typography} from "@material-ui/core";
import {ModelProvider} from "@rx-suite/ui/build";
import {BreadModelListBadge} from "../../../components/generic/bread_model_list_badges/BreadModelListBadge";
import {FormProps, PaddedPaper} from "@rx-suite/ui";
import {MachineTypeImage} from "../../../components/machine/machine_worsktation/MachineTypeImage";
import {MachineTypeStore} from "../../../stores/MachineTypeStore";
import {TabsContainer} from "../../../components/generic/TabsContainer";
import {t} from "@lingui/macro";
import {MachineProductionView} from "../../../components/machine_data/MachineProductionView";
import {MachineStateBadge} from "../../../components/generic/MachineStateBadge";
import {getLastMachineState} from "../../../stores/MachineStore";
import {MachineManualsView} from "../../../components/machine_data/MachineManualsView";

const useStyles = makeStyles((theme) => ({
    divider: {
        marginTop: theme.spacing(1),
    },
    machineTypeName: {
        fontWeight: 'bold'
    }
}));

export const MachineWorkstation:React.FunctionComponent<FormProps> = observer(({ model }) => {
    const classes = useStyles();
    const [lastState, setLastState] = React.useState<any>(null)
    const [loadingState, setLoadingState] = React.useState<boolean>(false)

    const machineGroups = React.useMemo(() => {
        return MachineGroupStore.models.filter((group) => {
            return model.machine_group_ids.includes(group.id)
        })
    }, [MachineGroupStore.models, model])

    const machineType = React.useMemo(() => {
        return MachineTypeStore.models.find(type => type.id == model.machine_type_id)
    }, [MachineTypeStore.models]);

    React.useEffect(() => {
        const getLastState = async () => {
            setLoadingState(true)
            const res = await getLastMachineState(model.id as string);
            setLastState(res)
            setLoadingState(false)
        }
        getLastState();
    }, [model]);

    return(
        <div>
            <PaddedPaper>
                <ModelProvider value={model}>
                    <Grid container>
                        <MachineTypeImage type={machineType}/>
                        <Grid item>
                            <Typography variant={'h4'}>{model.extendedName}</Typography>
                            {machineType && <Typography variant={'caption'} className={classes.machineTypeName}>{machineType.display_name}</Typography>}
                            <Grid container>
                                {machineGroups.map((group) => {
                                    return <BreadModelListBadge text={group.name} color={group.color}/>
                                })}
                            </Grid>
                            <MachineStateBadge lastState={lastState} isLoading={loadingState}/>
                        </Grid>
                    </Grid>
                </ModelProvider>
                <Divider className={classes.divider}/>
                <TabsContainer
                    variant={"scrollable"}
                    scrollButtons={"auto"}
                    tabs={[
                        {
                            label: t`Production View`,
                            component: <MachineProductionView model={model} />,
                            defaultTab: true
                        },
                        {
                            label: t`Data View`,
                            component: <MachineDataView model={model} />
                        },
                        {
                            label: t`Manuals`,
                            component: <MachineManualsView type={machineType}/>
                        }
                    ]}
                />
            </PaddedPaper>
        </div>
    )
});
