import {dataStorePermission, PasswordResetForm} from "@rx-suite/ui";
import ShoppingCartIcon from '@material-ui/icons/ShoppingCart';
import DirectionsIcon from '@material-ui/icons/Directions';
import MemoryIcon from '@material-ui/icons/Memory';
import ListIcon from '@material-ui/icons/List';
import ListAltIcon from '@material-ui/icons/ListAlt';
import ShoppingBasketIcon from '@material-ui/icons/ShoppingBasket';
import StorageIcon from '@material-ui/icons/Storage';
import ColorLensIcon from '@material-ui/icons/ColorLens';
import {JobsBreadModel} from "./pages/JobsBreadModel";
import {t} from "@lingui/macro";
import {MachineGroupsBreadModel} from "./pages/machine_groups/MachineGroupsBreadModel";
import {MachineTypesBreadModel} from "./pages/machine_types/MachineTypesBreadModel";
import {ProductionSettingForm} from "./pages/production_settings/ProductionSettingForm";
import {DataArchiveSettings} from "./pages/DataArchiveSettings";
import SettingsIcon from '@material-ui/icons/Settings';
import {OrdersBreadModel} from "./pages/orders/OrdersBreadModel";
import {JobStore} from "./stores/JobStore";
import {AllOut, CloudUpload, Devices, FilterList, ListAlt, SubdirectoryArrowRight, ViewList,} from "@material-ui/icons";
import {BlockReuseSettings} from "./pages/BlockReuseSettings";
import {MachineStore} from "./stores/MachineStore";
import {OrderStore} from "./stores/OrderStore";
import {DataArchiveSettingStore} from "./stores/DataArchiveSettingStore";
import {CapabilityGroupStore} from "./stores/CapabilityGroupStore";
import {CapabilityStore} from "./stores/CapabilityStore";
import {MachineGroupStore} from "./stores/MachineGroupStore";
import {AddressStore} from "./stores/AddressStore";
import {BlockReuseSettingStore} from "./stores/BlockReuseSettingStore";
import {PushTargetStore} from "./stores/PushTargetStore";
import {MachineDataPushTargetStore} from "./stores/MachineDataPushTargetStore";
import {computedFn} from "mobx-utils";
import {BlockForm} from "./pages/blocks/BlockForm";
import {BlocksBreadModel} from "./pages/blocks/BlocksBreadModel";
import React from "react";
import {JobHistoryOperatorForm} from "./pages/job_history/JobHistoryOperatorForm";
import {BlockPickingStore} from "./stores/BlockPickingStore";
import {BlockPickingBreadModel} from "./pages/block-picking/BlockPickingBreadModel";
import {ProductionSettingStore} from "./stores/ProductionSettingStore";
import {ErrorFilterStore} from "./stores/ErrorFilterStore";
import {DataFilteringPage} from "./pages/data_filtering/DataFilteringPage";
import {MachinesWorkstationTable} from "./pages/machines/workstation/MachinesWorkstationTable";
import {CapabilitiesBreadModel} from "./pages/capabilities/CapabilitiesBreadModel";
import {CapabilityGroupsBreadModel} from "./pages/capability_groups/CapabilityGroupsBreadModel";
import {MachinesBreadModel} from "./pages/machines/settings/MachinesBreadModel";
import {AddressesBreadModel} from "./pages/addresses/AddressesBreadModel";
import {ColorForm} from "./pages/colors/ColorForm";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faIndustry} from "@rx-suite/pro-solid-svg-icons/faIndustry";
import {ProcessBookingWorkstation} from "./pages/process_booking_workstations/ProcessBookingWorkstation";
import {BlockPickingWorkstation} from "./pages/block-picking/BlockPickingWorkstation";
import {ProcessBookingWorkstationStore} from "./stores/ProcessBookingWorkstationStore";
import {ProcessBookingWorkstationBreadModel} from "./pages/process_booking_workstations/ProcessBookingWorkstationBreadModel";
import {BoxCoaterRecipeBreadModel} from "./pages/box_coater_recipes/BoxCoaterRecipeBreadModel";
import {BoxCoaterRecipeStore} from "./stores/BoxCoaterRecipeStore";
import {
  ForwardingTargetsInternalBreadModel
} from "./pages/data_forwarding/internal/ForwardingTargetsInternalBreadModel";
import {
  ForwardingTargetsExternalBreadModel
} from "./pages/data_forwarding/external/ForwardingTargetsExternalBreadModel";

export const getRoutes = computedFn(  (blockReuseSettings) => {

  const routes = [
    {
      label: t`Machines`,
      to: "/machines",
      exact: false,
      permission: dataStorePermission(MachineStore),
      Component: MachinesWorkstationTable,
      Icon: MemoryIcon
    },
    {
      label: t`Orders`,
      exact: false,
      to: "/orders",
      permission: dataStorePermission(OrderStore),
      Icon: ShoppingBasketIcon,
      children: [
        {
          label: t`All Orders`,
          to: "/all",
          exact: false,
          Component: OrdersBreadModel,
          Icon: ShoppingBasketIcon,
        },
        {
          label: t`All Jobs`,
          to: "/jobs",
          exact: false,
          Component: JobsBreadModel,
          permission: dataStorePermission(JobStore),
          Icon: ShoppingCartIcon
        },
      ]
    },
    {
      label: t`Block Pieces`,
      to: '',
      exact: false,
      Icon: AllOut,
      shouldMount: () => { return blockReuseSettings && blockReuseSettings.enable_server },
      children: [
        {
          label: t`Search by DMC`,
          to: '/blocks/search',
          exact: false,
          Component: BlockForm
        },
        {
          label: t`All Block Pieces`,
          to: '/blocks',
          exact: false,
          Icon: ViewList,
          Component: BlocksBreadModel
        }
      ]
    },
    {
      label: t`Block Picking`,
      to: '',
      exact: false,
      permission: {
        target: 'BlockPicking',
        action: 'read'
      },
      children: BlockPickingStore.getAll().map( station => (
          {
            label: station.name,
            to: `/block_picking_station/${station.id}`,
            exact: false,
            Component: BlockPickingWorkstation,
            props: {model: station}
          }
      ))
    },
    {
      label: t`Process Booking`,
      to: '',
      exact: false,
      permission: {
        target: 'ProcessBookingWorkstation',
        action: 'read'
      },
      children: ProcessBookingWorkstationStore.getAll().map( station => (
          {
            label: station.name,
            to: `/process_booking_workstation/${station.id}`,
            exact: false,
            Component: ProcessBookingWorkstation,
            props: {model: station}
          }
      ))
    },
    {
      label: t`Job History`,
      to: '/job_history',
      exact: false,
      Component: JobHistoryOperatorForm
    },
    {
      label: t`Settings`,
      to: "/settings",
      exact: true,
      Icon: SettingsIcon,
      children: [
        {
          label: t`Production`,
          to: "/production_settings",
          exact: false,
          permission: dataStorePermission(ProductionSettingStore),
          Component: ProductionSettingForm,
          Icon: () => <FontAwesomeIcon icon={faIndustry} style={{height: '22px', width: '22px'}}/>,
        },
        {
          label: t`Colors`,
          to: "/colors",
          exact: false,
          Component: ColorForm,
          Icon: ColorLensIcon
        },
        {
          label: t`Capabilities`,
          to: "/capabilities",
          exact: false,
          permission: dataStorePermission(CapabilityStore),
          Component: CapabilitiesBreadModel,
          shouldMount: () => false, //JUNE 24 2022 - XBA : disabling these for now as they aren't used
          Icon: ListIcon
        },
        {
          label: t`Capability Groups`,
          to: "/capability_groups",
          exact: false,
          permission: dataStorePermission(CapabilityGroupStore),
          Component: CapabilityGroupsBreadModel,
          shouldMount: () => false, //JUNE 24 2022 - XBA : disabling these for now as they aren't used
          Icon: ListAltIcon
        },
        {
          label: t`Data Archiving`,
          to: "/data",
          exact: false,
          permission: dataStorePermission(DataArchiveSettingStore),
          Component: DataArchiveSettings,
          Icon: StorageIcon
        },
        {
          label: t`Machines`,
          to: "/machines",
          exact: false,
          permission: dataStorePermission(MachineStore),
          Component: MachinesBreadModel,
          Icon: MemoryIcon
        },
        {
          label: t`Machine Groups`,
          to: "/machine_groups",
          exact: false,
          permission: dataStorePermission(MachineGroupStore),
          Component: MachineGroupsBreadModel,
          Icon: MemoryIcon
        },
        {
          label: t`Machine Types`,
          to: "/machine_types",
          exact: false,
          Component: MachineTypesBreadModel,
          Icon: MemoryIcon
        },
        {
          label: t`Addresses`,
          to: "/addresses",
          exact: false,
          permission: dataStorePermission(AddressStore),
          Component: AddressesBreadModel,
          shouldMount: () => false, //JUNE 24 2022 - XBA : disabling these for now as they aren't used
          Icon: DirectionsIcon
        },
        {
          label: t`ReUse Server`,
          to: "/blocks",
          exact: false,
          permission: dataStorePermission(BlockReuseSettingStore),
          Component: BlockReuseSettings,
          Icon: AllOut
        },
        {
          label: t`Workstations`,
          to: '',
          exact: false,
          Icon: Devices,
          children: [
            {
              label: t`Block Picking`,
              to: '/block_pickings',
              exact: false,
              Icon: SubdirectoryArrowRight,
              permission: dataStorePermission(BlockPickingStore),
              Component: BlockPickingBreadModel
            },
            {
              label: t`Process Booking`,
              to: '/process_booking_workstations',
              exact: false,
              permission: dataStorePermission(ProcessBookingWorkstationStore),
              Component: ProcessBookingWorkstationBreadModel,
              Icon: SubdirectoryArrowRight
            },
          ]
        },
        {
          label: t`Data Forwarding`,
          to: '',
          exact: false,
          Icon: CloudUpload,
          children: [
            {
              label: t`Internal Forwarding`,
              to: '/data_forwarding/internal',
              exact: false,
              permission: dataStorePermission(PushTargetStore),
              Component: ForwardingTargetsInternalBreadModel,
              Icon: SubdirectoryArrowRight
            },
            {
              label: t`External Forwarding`,
              to: '/data_forwarding/external',
              exact: false,
              permission: dataStorePermission(MachineDataPushTargetStore),
              Component: ForwardingTargetsExternalBreadModel,
              Icon: SubdirectoryArrowRight
            },
          ]
        },
        {
          label: t`Box Coater Recipes`,
          to: "/box_coater_recipes",
          exact: false,
          Component: BoxCoaterRecipeBreadModel,
          permission: dataStorePermission(BoxCoaterRecipeStore),
          Icon: ListAlt
        },
        {
          label: t`Custom Data Filters`,
          to: '/data_filtering',
          exact: false,
          Icon: FilterList,
          permission: dataStorePermission(ErrorFilterStore),
          Component: DataFilteringPage
        }
      ]
    },
    {
      to: "/password_reset/:user/:token",
      exact: false,
      Component: PasswordResetForm,
    }
  ];

  return routes;
});
