import {attribute, DataStore, model, Model} from '@rx-suite/data';

import {t} from "@lingui/macro";
import {computed} from "mobx";

@model({
    eager: true,
    transportLayer: "/api/machine_types",
    routingInfo: {
        create: "/settings/machine_types/create",
        update: "/settings/machine_types/:id/edit",
        read: "/settings/machine_types/:id"
    }
})
export class MachineTypeModel extends Model {
    @attribute()
    id: number = -1;

    @attribute({label: t`Name`})
    name: string = "";

    @attribute({label: t`Display Name`})
    display_name: string = "";

    @attribute({label: t`Category`})
    category: string = "";

    @attribute()
    image_url: string = "";

    @attribute()
    machine_state_enabled: boolean = false;

    @attribute()
    job_state_enabled: boolean = false;

    @attribute()
    error_enabled: boolean = false;

    @attribute()
    maintenance_enabled: boolean = false;

    @attribute()
    process_data_enabled: boolean = false;

    @attribute()
    event_data_enabled: boolean = false;

    @attribute()
    calibration_data_enabled: boolean = false;

    @attribute()
    no_machine_manuals: boolean = false;

    @attribute()
    has_maintenance_manuals: boolean = false;

    @attribute()
    has_operating_manuals: boolean = false;

    @attribute()
    manual_languages: any = null;

    @computed
    get isBoxCoater(): boolean {
        return this.category === 'box_coater';
    }

    getManual = async (manualType: string, manualLanguage: string) => {
        const response = await fetch(`/api/machine_types/${this.id}/download_manual/?manualType=${manualType}&manualLanguage=${manualLanguage}`, {
            method: 'GET',
            headers: {
                'Content-Type': 'application/pdf'
            },
            responseType: 'blob'
        })

        if (!response.ok) {
            throw new Error(`Something went wrong while downloading the ${manualType} manual. Please contact your administrator`)
        }

        const blob = await response.blob();
        // Make the filename similar to original manual name
        const filename = `${this.display_name.replaceAll("-", "_")}_${manualType}_${manualLanguage}.pdf`

        const url = window.URL.createObjectURL(new Blob([blob]));
        const link = document.createElement('a');
        link.href = url;
        link.setAttribute('download', filename);
        document.body.appendChild(link);
        link.click();
        link.parentNode.removeChild(link);
    }

    constructor() {
        super();
        super.setup();
    }
}

export const MachineTypeStore = MachineTypeModel.store as DataStore<MachineTypeModel>;