##
# this shouldn't be run async
# use `perform_now` when running this
class DeleteExpiredDataJob < ApplicationJob
  queue_as :default

  include ArchiveHelpers

  def perform
    before_work = Time.current.to_f
    expired_date = data_expired_date
    deleted_objects = 0
    # Delete orders (which deletes the order and its associated jobs)
    deleted_objects += Order.delete_expired_before(expired_date)
    # Delete jobs (these are loose jobs that aren't tied to an order)
    deleted_objects += Job.delete_expired_before(expired_date)
    # Delete machine states
    deleted_objects += MachineState.delete_before(expired_date)
    # Delete errors
    deleted_objects += Error.delete_before(expired_date)
    # Delete maintenances
    deleted_objects += Maintenance.delete_before(expired_date)
    # Delete events
    deleted_objects += Event.delete_before(expired_date)
    # Delete calibrations
    deleted_objects += Calibration.delete_before(expired_date)

    deleted_objects += JobBreakage.delete_before(expired_date)

    deleted_objects += clear_stale_kpi_cache(expired_date)

    deleted_objects += Batch.delete_before(expired_date)

    after_work = Time.current.to_f
    Rails.logger.info "Delete cycle time: #{((after_work - before_work) * 1000).truncate(4)} ms -- Deleted objects: #{deleted_objects}"
  end

  def clear_stale_kpi_cache(date)
    deleted_objects = 0
    kpi_cache_max_delete = DataArchiveSetting.instance.delete_count_kpi_cache

    kpis_to_delete = [KpiMachineStateDuration, KpiRoutingKickout, KpiJobState, KpiMachineErrorCount, KpiMachineAbortCount]

    ActiveRecord::Base.connected_to(shard: :primary, role: :writing) do
      kpis_to_delete.each do |kpi|
        deleted_objects += kpi.where(kpi.arel_table[:time].lt(date)).limit(kpi_cache_max_delete).delete_all
      end
    end
    deleted_objects
  end

  def max_attempts
    4
  end
end
