class KpiMachineStateJob < ApplicationJob
  include ArchiveHelpers
  queue_as :kpi

  def perform(machine_state)
    ActiveRecord::Base.connection_pool.with_connection do

      # Max is used so that we dont have a calculated duration bigger than 10 precision with scale 3 which ends up being 9999999.999
      max_calculated_duration = 9999999.999
      # All these changes must happen at once to guarantee cache integrity
      MachineState.transaction do
        # KPI - Current Machine State
        machine_state.machine.set_current_state(machine_state)

        # KPI - Machine State Duration

        # If the machine state is from more than 31 days ago, it is surely a machine time sync problem, ignore setting its duration
        if !time_exists_in_primary?(machine_state.time)
          return
        end

        previous_state = machine_state.previous_in_time
        next_state = machine_state.next_in_time

        unless previous_state.nil?
          previous_calculated_duration = if machine_state.time - previous_state.time > max_calculated_duration
                                          max_calculated_duration
                                        else
                                          machine_state.time - previous_state.time
                                        end
          previous_state.update(calculated_duration: previous_calculated_duration)
        end

        unless next_state.nil?
          next_calculated_duration = if next_state.time - machine_state.time > max_calculated_duration
                                        max_calculated_duration
                                      else
                                        next_state.time - machine_state.time
                                      end
          machine_state.update(calculated_duration: next_calculated_duration)
        end

        # KPI - Machine State duration cache
        # If the machine state coming in not within the now bucket, bust old cache entries so they are re-calculated
        if machine_state.time <= KpiHelpers.kpi_bucket_time(Time.zone.now)
          #TODO: this could be a trigger for Rx-Alerting to send time sync error?
          end_time = machine_state.calculated_duration.nil? ? (Time.zone.now + KpiHelpers.cache_entry_size) : KpiHelpers.kpi_bucket_time(machine_state.time + machine_state.calculated_duration)+KpiHelpers.cache_entry_size
          buckets = KpiHelpers.time_buckets_between(machine_state.time, end_time)

          KpiMachineStateDuration.where(machine_id: machine_state.machine.id, dirty: false)
                                 .where(KpiMachineStateDuration.arel_table[:time].gteq(buckets[0]).and(KpiMachineStateDuration.arel_table[:time].lteq(buckets[-1])))
                                 .update_all(dirty: true)
        end
      end
    end
  end
end
