module PlannedProductionTimeWithinShiftCalculator
  extend ActiveSupport::Concern

  # passing the shift range and a active between range so that we dont refetch outside the cache for each active range
  def local_cache_get_active_time_between_for_shift_range(shift_range_start, shift_range_end, bucket_start, bucket_end)
    return 0 if bucket_start > bucket_end

    ranges = ShiftCache.get_shift_ranges(shift_range_start, shift_range_end)[:ranges]

    active_time = 0
    ranges.each do |range|
      shift_start = ShiftTimeHelpers.ensure_shift_time_fits_cache(range[:start])
      shift_end = ShiftTimeHelpers.ensure_shift_time_fits_cache(range[:end])

      # skip shifts that dont overlap with our bucket time
      next if bucket_end <= shift_start || bucket_start >= shift_end

      #base case, our bucket start and end is within the shift, return active time, we're done
      return bucket_end - bucket_start if (shift_start <= bucket_start && bucket_end <= shift_end)

      #if the entire shift is within our bucket, add to active time and continue
      next active_time += shift_end - shift_start if bucket_start <= shift_start && bucket_end >= shift_end

      # some overlap on the start side, need to get from shift start to bucket_end
      next active_time += bucket_end - shift_start  if bucket_start <= shift_start && bucket_end <= shift_end

      # some overlap on the end side, get from bucket start to shift end
      next active_time += shift_end - bucket_start if bucket_end >= shift_end && bucket_start >= shift_start

      Rails::logger.warn "Edge case found for planned production calculations: {shift_start: #{shift_start}, shift_end: #{shift_end}, bucket_start: #{bucket_start}, bucket_end: #{bucket_end}"
    end
    active_time
  end
end
