module MachineConcern
  extend ActiveSupport::Concern
  included do
    def target_to_id(target)
      self.class.target_to_id(target)
    end

    def target_to_name(target)
      self.class.target_to_name(target)
    end

    def parsed_targets
      @_parsed_targets ||= targets.map do |id|
        parsed_target(id)
      end
    end

    def parsed_row_targets(targets)
      @_parsed_targets ||= targets.map do |id|
        parsed_target(id)
      end
    end

    def parsed_target(id)
      category, ref = id.split("-")
      case category
      when 'm'
        requested_machines.find { |m| m.id.to_s == ref }
      when 'g'
        requested_machine_groups.find { |g| g.id.to_s == ref }
      end
    end

    def requested_machines
      @_requested_machines ||= Machine.where(id: targets.select do |id|
        id[0] == 'm'
      end.map do |id|
        id.split("-")[1]
      end).all
    end

    def requested_machine_groups
      @_requested_machine_groups ||= MachineGroup.where(id: targets.select do |id|
        id[0] == 'g'
      end.map do |id|
        id.split("-")[1]
      end).includes(:machines).all
    end

    def target_from_id(id)
      type, ref = id.split('-')
      if type == 'm'
        requested_machines.find { |m| m.id.to_s == ref }
      elsif type == 'g'
        requested_machine_groups.find { |g| g.id.to_s == ref }
      end
    end

    class << self
      def target_to_id(target)
        if target.is_a? Machine
          "m-#{target.id}"
        elsif target.is_a? MachineGroup
          "g-#{target.id}"
        end
      end

      def target_to_name(target)
        if target.is_a? Machine
          "#{target.name} (#{target.sn})"
        elsif target.is_a? MachineGroup
          target.name
        end
      end
    end
  end
end