module MachineKpiCalculator
  class AbortedJobRatio < MachineKpiCalculator

    include KpiTableHandler

    class << self
      def get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options: {})
        kpi = AbortedJobRatio.new(start_time, end_time, timeframe, machine_ids, options)
        kpi.run
      end
    end

    def initialize(start_time, end_time, timeframe, machine_ids, options)
      super(start_time, end_time, timeframe, machine_ids, options)
    end

    def handlers
      [
        {
          key: :job_states,
          handler: KpiTableHandler::JobStateCountKpiHandler,
          params: {
            job_states: %w[finished aborted]
          }
        }
      ]
    end

    def build_results
      data[:job_states].each do |k, v|
        # ppt calculations nil out buckets that are not within shifts, and we need to keep them nil until they reach the front-end
        next data[:job_states][k] = nil if use_planned_production_time? && v[:aborted].nil? && v[:finished].nil?

        aborted = (v[:aborted] || 0)
        finished = (v[:finished] || 0)
        processed = aborted + finished

        if ProductionSetting.metric_is_pair?
          processed /= 2
          aborted /= 2
        end

        if processed == 0
          data[:job_states][k] = 0
        else
          data[:job_states][k] = ((aborted / processed.to_f)*100)
        end
      end
    end

    def build_results_per_machine
      data[:job_states].each do |machine_id, hash|
        hash.each do |k, v|
          next data[:job_states][machine_id][k] = nil if use_planned_production_time? && (v[:aborted].nil? && v[:finished].nil?)

          aborted = (v[:aborted] || 0)
          finished = (v[:finished] || 0)
          processed = aborted + finished

          if ProductionSetting.metric_is_pair?
            processed /= 2
            aborted /= 2
          end

          if processed == 0
            data[:job_states][machine_id][k] = 0
          else
            data[:job_states][machine_id][k] = ((aborted / processed.to_f)*100)
          end
        end
      end
    end

    def format_results
      wrap_with_percent
    end

    def wrap_with_percent
      if aggregate_machines?
        @results.each do |time, bucket|
          @results[time] = {percent: bucket}
        end
      else
        @results.each do |machine_id, hash|
          hash.each do |time, bucket|
            @results[machine_id][time] = {percent: bucket}
          end
        end
      end
    end
  end
end