module MachineKpiCalculator
  class Throughput < MachineKpiCalculator

    include KpiTableHandler

    class << self
      def get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options)
        kpi = Throughput.new(start_time, end_time, timeframe, machine_ids, options)
        kpi.run
      end
    end

    def initialize(start_time, end_time, timeframe, machine_ids, options)
      super(start_time, end_time, timeframe, machine_ids, options)
    end

    def handlers
      [
        {
          key: :job_states,
          handler: KpiTableHandler::JobStateCountKpiHandler,
          params: {
            job_states: ['finished']
          }
        }
      ]
    end

    def build_results
      data[:job_states].each do |k,v|
        next data[:job_states][k] = nil if v[:finished].nil?

        data[:job_states][k] = if ProductionSetting.metric_is_pair?
                                 (v[:finished] || 0) / 2
                               else
                                 v[:finished]
                               end
      end
    end

    def build_results_per_machine
      data[:job_states].each do |machine_id, hash|
        hash.each do |k,v|
          next data[:job_states][machine_id][k] = nil if v[:finished].nil?

          data[:job_states][machine_id][k] = if ProductionSetting.metric_is_pair?
                                               v[:finished] / 2
                                             else
                                               v[:finished]
                                             end
        end
      end
    end
  end
end