module MachineKpiCalculator
  class Utilization < MachineKpiCalculator

    include KpiTableHandler
    include SingleValueBucketCalculations

    class << self
      def get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options)
        kpi = Utilization.new(start_time, end_time, timeframe, machine_ids, options)
        kpi.run
      end
    end

    def initialize(start_time, end_time, timeframe, machine_ids, options)
      super(start_time, end_time, timeframe, machine_ids, options)
    end

    def handlers
      [
        {
          key: :machine_state_duration,
          handler: KpiTableHandler::MachineStateDurationKpiHandler,
          params: {
            machine_states: ['processing']
          }
        }
      ]
    end

    # Returns a hash of time buckets and the sum of time in 'utilization' by all specified machines
    # Utilization is expressed in a number of seconds unless 'as_percent' is passed in as an option
    # in which case the value returned is a percentage value.
    # ex:
    # {
    #   {13h00 01/01/2022 : 1600}
    #   {14h00 01/01/2022 : 747}
    # }
    def build_results
      data[:machine_state_duration].each {|k,v| data[:machine_state_duration][k] = v[:processing]}
    end

    def build_results_per_machine
      data[:machine_state_duration].each do |machine_id, hash|
        hash.each {|k,v| data[:machine_state_duration][machine_id][k] = v[:processing]}
      end
    end

    def percent_buckets(row, m_count)
      if timeframe == Timeframe::ALL
        return row[:percent] = nil if row[:count].nil?

        bucket_size = bucket_size_for_timeframe(nil)
        return row[:percent] = 0 if bucket_size == 0

        row[:percent] = ((row[:count] / (bucket_size * m_count)) * 100).to_f.round(2)
      else
        row.each do |time, col|
          next row[time][:percent] = nil if col[:count].nil?

          bucket_size = bucket_size_for_timeframe(time)
          next row[time][:percent] = 0 if bucket_size == 0

          row[time][:percent] = ((col[:count] / (bucket_size * m_count)) * 100).to_f.round(2)
        end
      end
    end
  end
end