module MachineTranslator
  class MachineTranslator
    class InvalidTranslatorHandler < StandardError; end
    class InvalidTranslationType < StandardError; end

    class << self
      def get_translator(translator_class)
        case translator_class
        when "MeiEdger"
          MeiEdger.new
        else
          raise InvalidTranslatorHandler
        end
      end

      def job_state_type
        :job_state
      end

      def machine_state_type
        :machine_state
      end

      def error_type
        :errors
      end

      def process_data_type
        :process_data
      end
    end

    def get_translation(params, type)
      case type
      when :machine_state
        machine_state_translation(params)
      when :job_state
        job_state_translation(params)
      when :errors
        errors_translation(params)
      when :process_data
        process_data_translation(params)
      else
        raise InvalidTranslationType
      end
    end

    def machine_state_translation(params)
      raise NotImplementedError
    end

    def job_state_translation(params)
      raise NotImplementedError
    end

    def errors_translation(params)
      raise NotImplementedError
    end

    def process_data_translation(params)
      raise NotImplementedError
    end
  end
end