class ShiftCache
  class << self
    def get_shift_ranges(start_time, end_time)
      Rails.cache.fetch([self, :shift_range, start_time, end_time], expires_in: 10.minutes) do
        RxModule::Communicator::Shifts.active_ranges_between(start_time, end_time)
      end
    end

    def get_active_time_between(start_time, end_time)
      # even if the times would change a lot, rails deletes expired cache entries automatically
      Rails.cache.fetch([self, :active_time, start_time, end_time], expires_in: 10.minutes) do
        RxModule::Communicator::Shifts.active_time_between(start_time, end_time)
      end
    end

    def is_within_shifts(time, interval_start_time, interval_end_time)
      ranges = get_shift_ranges(interval_start_time, interval_end_time)[:ranges]
      ranges.any? { |range| (Time.parse(range[:start])..Time.parse(range[:end])).include? time }
    end
  end
end