class ShiftHandler
  @shifts = []
  @active_shifts = []

  def self.has_active_shift?(ids)
    #returns bool on if theres active shifts in the shift_reference array
    @active_shifts.any? {|active_shift| ids.include? active_shift[:shift][:id]}
  end

  def self.get_active_shifts_for_block_picking(ids)
    @active_shifts.select {|active_shift| ids.include? active_shift[:shift][:id]}
  end

  def self.shifts_exists?(ids)
    #Checks whether all shift ids exist in the shift cache
    ids.each do |id|
      return false unless @shifts.any? {|shift| shift[:id] == id}
    end
    true
  end

  def self.fetch_shifts
    resp = RxModule::Communicator::Shifts.shifts
    handle_shift_deletion(resp[:models])
    @shifts = resp[:models]
    fetch_current_shifts
    resp
  end

  def self.fetch_current_shifts
    resp = RxModule::Communicator::Shifts.current_shifts
    handle_shift_swapping(resp[:models])
    resp
  end

  def self.fetch_shift(id)
    RxModule::Communicator::Shifts.shift(id)
  end

  def self.shifts
    @shifts
  end

  def self.active_shifts
    @active_shifts
  end

  private

  def self.handle_shift_swapping(new_active_shifts)
    #This save on resources, we can do all of our calculations on the ids of the shifts themselves.
    # We release the count of all shifts that are either new, or got removed.
    new_active_shift_ids = new_active_shifts.map { |new_active_shift| new_active_shift[:shift][:id] }
    active_shift_ids = @active_shifts.map { |active_shift| active_shift[:shift][:id] }
    shift_broadcast_ids = new_active_shift_ids - active_shift_ids | active_shift_ids - new_active_shift_ids
    @active_shifts = new_active_shifts
    shift_broadcast_ids.each do |shift_broadcast_id|
      ShiftReference.where(hub_shift_id: shift_broadcast_id).each do |shift_reference|
        shift_reference.block_pickings.each do |block_picking|
          Rails::logger::info "Releasing count for Block Picking #{block_picking.name}"
          block_picking.release_count
        end
      end
    end
  end

  def self.handle_shift_deletion(new_shifts)
    @shifts.each do |shift|
      next if new_shifts.any? {|new_shift| new_shift[:id] == shift[:id]}
      ShiftReference.where(hub_shift_id: shift[:id]).each do |shift_reference|
        #TODO: need to ask xavier if this removes the block picking or just removes the shift association
        shift_reference.block_pickings.destroy_all
      end
    end
  end
end
