class ApplicationRecord < RxModule::ApplicationRecord
  self.abstract_class = true
  connects_to shards: {
    primary: {writing: :primary, reading: :primary},
    archive: {writing: :archive, reading: :archive}
  }

  class << self
    #This is a temporary fix until the sqlserver adapter bug for pluck is fixed
    def list_values(column)
      relation_tree = accessor_array_to_relation_tree([column])
      arel_col = get_arel(column, false)
      qualified_col = "\"#{arel_col.relation.name}\".\"#{arel_col.name}\""
      pluck_column = arel_col.name
      left_outer_joins(relation_tree).select(qualified_col).distinct.to_a.pluck(pluck_column)
    end
  end

  def should_broadcast?
    false
  end

  def should_archive?
    true
  end

  after_create_commit do
    begin
      if ActiveRecord::Base.current_shard == :primary && should_archive?
        ArchiveTask.queue_create(self)
      end
    rescue => err
      Rails.logger.error "Error while creating archive task: #{err}"
    end

  end

  after_update_commit do
    begin
      if ActiveRecord::Base.current_shard == :primary && should_archive?
        ArchiveTask.queue_update(self)
      end
    rescue => err
      Rails.logger.error "Error while creating archive task: #{err}"
    end
  end

  def to_json(*args)
    render_jbuilder_partial
  rescue
    super(*args)
  end
end
