module MachineKpi
  extend ActiveSupport::Concern

  include MachineKpiCalculator

  class << self
    def ensure_base_options(options)
      options[:aggregate_machines] = true if options[:aggregate_machines].nil?
    end

    ### Machine States
    def utilization_between(start_time, end_time, timeframe, machine_ids, options: {})
      ensure_base_options(options)
      MachineKpiCalculator::Utilization.get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options)
    end

    def uptime_between(start_time, end_time, timeframe, machine_ids, options: {})
      ensure_base_options(options)
      MachineKpiCalculator::Uptime.get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options)
    end

    def state_breakdown_between(start_time, end_time, timeframe, machine_ids, options: {})
      ensure_base_options(options)
      MachineKpiCalculator::MachineStateBreakdown.get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options)
    end

    def downtime_between(start_time, end_time, timeframe, machine_ids, options: {})
      ensure_base_options(options)
      MachineKpiCalculator::Downtime.get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options)
    end

    def time_in_error_between(start_time, end_time, timeframe, machine_ids, options: {})
      ensure_base_options(options)
      MachineKpiCalculator::ErrorTime.get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options)
    end


    def overall_equipment_effectiveness_between(start_time, end_time, timeframe, machine_ids, options: {})
      ensure_base_options(options)
      MachineKpiCalculator::OverallEquipmentEffectiveness.get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options: options)
    end

    def mean_time_to_restore_between(start_time, end_time, timeframe, machine_ids, options: {})
      ensure_base_options(options)
      MachineKpiCalculator::MeanTimeToRestore.get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options: options)
    end

    def mean_time_between_failures_between(start_time, end_time, timeframe, machine_ids, options: {})
      ensure_base_options(options)
      MachineKpiCalculator::MeanTimeBetweenFailures.get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options: options)
    end

    ### Job States
    def job_state_breakdown_between(start_time, end_time, timeframe, machine_ids, options: {})
      ensure_base_options(options)
      MachineKpiCalculator::JobStateBreakdown.get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options)
    end

    def throughput_between(start_time, end_time, timeframe, machine_ids, options: {})
      ensure_base_options(options)
      MachineKpiCalculator::Throughput.get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options)
    end

    def aborted_job_ratio_between(start_time, end_time, timeframe, machine_ids, options: {})
      ensure_base_options(options)
      MachineKpiCalculator::AbortedJobRatio.get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options: options)
    end

    def started_between(start_time, end_time, timeframe, machine_ids, options: {})
      options.merge!({aggregate_machines: true})
      MachineKpiCalculator::JobStateStarted.get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options: options)
    end

    def started_between_per_machine(start_time, end_time, timeframe, machine_ids, options: {})
      options.merge!({aggregate_machines: false})
      MachineKpiCalculator::JobStateStarted.get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options: options)
    end

    def box_coater_batches_run_between(start_time, end_time, machine_ids, options: {})
      MachineKpiCalculator::BoxCoaterBatches::BatchRuns.get_for_period_and_machines(start_time, end_time, machine_ids, options: options)
    end

    def box_coater_batches_count_between(start_time, end_time, timeframe, machine_ids, options: {})
      MachineKpiCalculator::BoxCoaterBatches::BatchCounts.get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options: options)
    end

    ### Errors
    def top_errors_between(start_time, end_time, timeframe, machine_ids, options: {})
      ensure_base_options(options)
      MachineKpiCalculator::TopErrors.get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options)
    end

    def error_trends_between(start_time, end_time, timeframe, machine_ids, options: {})
      ensure_base_options(options)
      MachineKpiCalculator::ErrorTrends.get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options)
    end

    ### Aborts
    def top_aborts_between(start_time, end_time, timeframe, machine_ids, options: {})
      ensure_base_options(options)
      MachineKpiCalculator::TopAborts.get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options)
    end

    def abort_trends_between(start_time, end_time, timeframe, machine_ids, options: {})
      ensure_base_options(options)
      MachineKpiCalculator::AbortTrends.get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options)
    end


    ### Kickout reasons
    def aggregated_kickouts_between(start_time, end_time, timeframe, machine_ids, options: {})
      options.merge!({aggregate_machines: true})
      MachineKpiCalculator::SummedRoutingKickouts.get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options: options)
    end

    def aggregated_kickouts_between_per_machine(start_time, end_time, timeframe, machine_ids, options: {})
      options.merge!({aggregate_machines: false})
      MachineKpiCalculator::SummedRoutingKickouts.get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options: options)
    end

    def kickouts_between(start_time, end_time, timeframe, machine_ids, options: {})
      MachineKpiCalculator::RoutingKickoutBreakdown.get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options: options)
    end

    def kickouts_between_per_machine(start_time, end_time, timeframe, machine_ids, options: {})
      options.merge!({aggregate_machines: false})
      MachineKpiCalculator::RoutingKickoutBreakdown.get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options: options)
    end

    def top_5_kickouts_between(start_time, end_time, timeframe, machine_ids, options: {})
      options.merge!({aggregate_machines: true, top_5: true})
      MachineKpiCalculator::RoutingKickoutBreakdown.get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options: options)
    end

    def top_5_kickouts_between_per_machine(start_time, end_time, timeframe, machine_ids, options: {})
      options.merge!({aggregate_machines: false, top_5: true})
      MachineKpiCalculator::RoutingKickoutBreakdown.get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options: options)
    end

    #EER
    def time_in_event_type_breakdown(start_time, end_time, timeframe, machine_ids, options: {})
      ensure_base_options(options)
      MachineKpiCalculator::BoxCoaterStateBreakdown.get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options: options)
    end

    def time_in_reporting_category_breakdown(start_time, end_time, timeframe, machine_ids, options: {})
      ensure_base_options(options)
      MachineKpiCalculator::BoxCoaterReportingCategoryBreakdown.get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options: options)
    end

    def box_coater_yield_between(start_time, end_time, timeframe, machine_ids, options: {})
      ensure_base_options(options)
      MachineKpiCalculator::BoxCoaterYield.get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options: options)
    end

    def box_coater_batch_loading_between(start_time, end_time, timeframe, machine_ids, options: {})
      ensure_base_options(options)
      MachineKpiCalculator::BoxCoaterBatch.get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options: options)
    end

    ## EVENTS

    def event_drl_finished_between(start_time, end_time, timeframe, machine_ids, options: {})
      ensure_base_options(options)
      MachineKpiCalculator::EventDrlFinishedData.get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options: options)
    end
  end

  ### Machine States
  def utilization_between(start_time, end_time, timeframe, options: {})
    MachineKpi.utilization_between(start_time, end_time, timeframe,[self.id], options: options)
  end

  def uptime_between(start_time, end_time, timeframe, options: {})
    MachineKpi.uptime_between(start_time, end_time, timeframe,[self.id], options: options)
  end

  def state_breakdown_between(start_time, end_time, timeframe, options: {})
    MachineKpi.state_breakdown_between(start_time, end_time, timeframe, [self.id], options: options)
  end

  def downtime_between(start_time, end_time, timeframe, options: {})
    MachineKpi.downtime_between(start_time, end_time, timeframe,[self.id], options: options)
  end

  def overall_equipment_effectiveness_between(start_time, end_time, timeframe, options: {})
    MachineKpi.overall_equipment_effectiveness_between(start_time, end_time, timeframe,[self.id], options: options)
  end

  def mean_time_to_restore_between(start_time, end_time, timeframe, options: {})
    MachineKpi.mean_time_to_restore_between(start_time, end_time, timeframe,[self.id], options: options)
  end

  def mean_time_between_failures_between(start_time, end_time, timeframe, options: {})
    MachineKpi.mean_time_between_failures_between(start_time, end_time, timeframe,[self.id], options: options)
  end

  ### Job States
  def throughput_between(start_time, end_time, timeframe, options: {})
    MachineKpi.throughput_between(start_time, end_time, timeframe,[self.id], options: options)
  end

  def aborted_job_ratio_between(start_time, end_time, timeframe, options: {})
    MachineKpi.aborted_job_ratio_between(start_time, end_time, timeframe, [self.id], options: options)
  end

  def started_between(start_time, end_time, timeframe, options: {})
    MachineKpi.started_between(start_time, end_time, timeframe, [self.id], options: options)
  end

  def started_between_per_machine(start_time, end_time, timeframe, options: {})
    MachineKpi.started_between_per_machine(start_time, end_time, timeframe, [self.id], options: options)
  end

  def box_coater_batches_run_between(start_time, end_time, timeframe, options: {})
    MachineKpi.box_coater_batches_run_between(start_time, end_time, [self.id], options: options)
  end

  def box_coater_batches_count_between(start_time, end_time, timeframe, options: {})
    MachineKpi.box_coater_batches_count_between(start_time, end_time, timeframe, [self.id], options: options)
  end

  ### Kickout Reasons
  def aggregated_kickouts_between(start_time, end_time, timeframe, options: {})
    MachineKpi.aggregated_kickouts_between(start_time, end_time, timeframe, [self.id], options: options)
  end

  def kickouts_between(start_time, end_time, timeframe, options: {})
    MachineKpi.kickouts_between(start_time, end_time, timeframe, [self.id], options: options)
  end

  def aggregated_kickouts_between_per_machine(start_time, end_time, timeframe, options: {})
    MachineKpi.aggregated_kickouts_between_per_machine(start_time, end_time, timeframe, [self.id], options: options)
  end

  def kickouts_between_per_machine(start_time, end_time, timeframe, options: {})
    MachineKpi.kickouts_between_per_machine(start_time, end_time, timeframe, [self.id], options: options)
  end

  def top_5_kickouts_between(start_time, end_time, timeframe, options: {})
    MachineKpi.top_5_kickouts_between(start_time, end_time, timeframe, [self.id], options: options)
  end

  def top_5_kickouts_between_per_machine(start_time, end_time, timeframe, options: {})
    MachineKpi.top_5_kickouts_between_per_machine(start_time, end_time, timeframe, [self.id], options: options)
  end
end
