module ProductionView
  extend ActiveSupport::Concern

  def build_production_view_report_data(start_time, end_time, machine_ids)
    data = components.map do |c| c[:component].new(start_time,
                                                   end_time,
                                                   machine_ids,
                                                   1).build(c[:args])
    end
    {time: Time.zone.now, data: data, start_time: start_time, end_time: end_time}
  end

  def performance_report_component
    if self.machine_type && self.machine_type.category == "box_coater"
      {
        component: ReportComponents::MachinePerformanceBatch,
        args: {}
      }
    else
      {
        component: ReportComponents::MachinePerformanceOverview,
        args: {
          uptime_target: ProductionSetting.instance.machine_uptime_target,
          utilization_target: ProductionSetting.instance.machine_utilization_target
        }
      }
    end
  end

  def components
    [
      performance_report_component,
      {
        component: ReportComponents::MachineTopErrorsBar,
        args: {addons: [:as_percent], aggregate_machines: false}
      },
      {
        component: ReportComponents::MachineTopAbortsBar,
        args: {colorize_series: true, addons: [:as_percent], aggregate_machines: false}
      }
    ]
  end
end


