# == Schema Information
#
# Table name: machine_types
#
#  id                       :bigint           not null, primary key
#  calibration_data_enabled :boolean          default(FALSE)
#  category                 :string(4000)
#  display_name             :string(4000)
#  error_enabled            :boolean          default(FALSE)
#  event_data_enabled       :boolean          default(FALSE)
#  image_url                :string(4000)
#  job_state_enabled        :boolean          default(FALSE)
#  machine_state_enabled    :boolean          default(FALSE)
#  maintenance_enabled      :boolean          default(FALSE)
#  name                     :string(4000)     not null
#  process_data_enabled     :boolean          default(FALSE)
#  seed_version             :integer          default(0)
#  system_default           :boolean          default(FALSE)
#  translator_class         :string(4000)
#  created_at               :datetime         not null
#  updated_at               :datetime         not null
#
class MachineType < ApplicationRecord
  has_many :machines
  has_many :error_filters, as: :filter_target
  has_many :abort_filters, as: :filter_target

  def should_broadcast?
    true
  end

  def capitalize_first_char(string_array)
    string_array.map do |string|
      string.capitalize
    end
  end

  def split_and_capitalize(string, split_by)
    split_string = string.split(split_by)
    split_string = capitalize_first_char(split_string)
    split_string.join("")
  end

  def manuals
    type_module = split_and_capitalize(self.category, "_") + "s"
    first_in_type_name_is_int = !!Integer(self.name[0]) rescue false
    if first_in_type_name_is_int
      split_name = self.name.split("_")
      split_name << split_name.shift
      type_class = capitalize_first_char(split_name).join("")
    else
      type_class = split_and_capitalize(self.name, "_")
    end
    machine_type = "MachineTypes::#{type_module}::#{type_class}".constantize
    machine_type.respond_to?(:machine_manuals) ? machine_type.machine_manuals : nil
  end

  def manual_languages
    unless manuals.nil?
      available_languages = [
        {label: 'English (EN)', value: 'en'},
        {label: 'Deutsch (DE)', value: 'de'},
        {label: 'Español (ES)', value: 'es'},
        {label: 'Français (FR)', value: 'fr'},
        {label: 'Italiano (IT)', value: 'it'},
        {label: '日本語 (JP)', value: 'ja'},
        {label: 'Polski (PL)', value: 'pl'},
        {label: 'Português (PT)', value: 'pt'}
      ]

      maintenance_opts = manuals[:maintenance] ? available_languages.filter{|al| manuals[:maintenance].keys().include? al[:value].to_sym} : []
      operating_opts = manuals[:operating] ? available_languages.filter{|al| manuals[:operating].keys().include? al[:value].to_sym} : []

      {
        maintenance_languages: maintenance_opts,
        operating_languages: operating_opts
      }
    else
      []
    end
  end
end
