# == Schema Information
#
# Table name: production_settings
#
#  id                         :bigint           not null, primary key
#  is_eer_lab                 :boolean          default(FALSE)
#  machine_manual_path        :string(4000)
#  machine_oee_target         :integer          default(70)
#  machine_uptime_target      :integer          default(70)
#  machine_utilization_target :integer          default(70)
#  max_job_number_length      :integer
#  rz_tolerance               :float            default(0.2)
#  simplified_machine_states  :boolean          default(TRUE)
#  throughput_metric          :integer          default("lens"), not null
#  tx_tolerance               :float            default(0.2)
#  ty_tolerance               :float            default(0.2)
#  created_at                 :datetime         not null
#  updated_at                 :datetime         not null
#
class ProductionSetting < ApplicationRecord
  enum :throughput_metric => [:lens, :pairs]

  def should_archive?
    false
  end

  def self.instance
    first_or_create(
      is_eer_lab: false,
      throughput_metric: 0, # lens
      machine_oee_target: 70,
      machine_utilization_target: 70,
      machine_uptime_target: 85,
      simplified_machine_states: false
    )
  end

  def self.use_eer_metrics?
    ProductionSetting.instance.is_eer_lab
  end

  def self.use_simple_machine_state_colors?
    ProductionSetting.instance.simplified_machine_states
  end

  def self.metric_is_pair?
    ProductionSetting.instance.throughput_metric == 'pairs'
  end

  def self.metric_is_lens?
    ProductionSetting.instance.throughput_metric == 'lens'
  end

  def self.max_job_num_length
    ProductionSetting.instance.max_job_number_length
  end

  def self.machine_manual_path
    ProductionSetting.instance.machine_manual_path
  end
end
