module ReportTargetValues
  extend ActiveSupport::Concern
  include KpiHelpers

  class_methods do
    def use_uptime_target(description="The uptime target (%) used in the overview chart.")
      parameter(
        :uptime_target,
        "Uptime Target (%)",
        description,
        :integer,
        min: 1,
        max: 100,
        default: default_uptime_target)
    end

    def use_utilization_target(description="The utilization target (%) used in the overview chart.")
      parameter(
        :utilization_target,
        "Utilization Target (%)",
        description,
        :integer,
        min: 1,
        max: 100,
        default: default_utilization_target)
    end

    def use_oee_target(description="The oee target (%) used in the overview chart.")
      parameter(
        :oee_target,
        "OEE Target (%)",
        description,
        :integer,
        min: 1,
        max: 100,
        default: default_oee_target)
    end

    def use_throughput_target(description="The throughput target used to color the cells.")
      parameter(
        :throughput_target,
        "Throughput Target",
        description,
        :integer,
        default: 0)
    end

    def use_aborted_target(description="The aborted target (%) used to color the cells.")
      parameter(
        :aborted_target,
        "Aborted Target (%)",
        description,
        :integer,
        min: 1,
        max: 100,
        default: 0)
    end

    def default_uptime_target
      ProductionSetting.instance.machine_uptime_target
    end

    def default_utilization_target
      ProductionSetting.instance.machine_utilization_target
    end

    def default_oee_target
      ProductionSetting.instance.machine_oee_target
    end
  end

  def uptime_target
    return self.default_uptime_target if @parameters[:uptime_target].nil?
    @parameters[:uptime_target]
  end

  def utilization_target
    return self.default_utilization_target if @parameters[:utilization_target].nil?
    @parameters[:utilization_target]
  end

  def oee_target
    return self.default_oee_target if @parameters[:oee_target].nil?
    @parameters[:oee_target]
  end

  def throughput_target
    @parameters[:throughput_target]
  end

  def aborted_target
    @parameters[:aborted_target]
  end
end