class LabProductivityReport < MachineTemplateReport
  include ReportPeriod
  include ReportTargetValues
  class << self
    def report_type
      "Lab Productivity Report"
    end

    def page_header
      parameter(
        :page_header,
        "Page Header",
        "Custom header for the page",
        :string
      )
    end

    def expand_machine_group
      parameter(
        :expand_machine_group,
        "Expand Machine Group",
        "Process each machine of the group individually",
        :boolean
      )
    end
  end

  expose('lab_productivity_report', report_type, "Overview of the performance for an individual machine or machine group.", "LabProductivityReport")

  use_machine_targets(true)
  page_header
  expand_machine_group
  use_planned_production_time
  use_utilization_target("The utilization target (%) used to color the cells.")
  use_uptime_target("The uptime target (%) used to color the cells.")
  use_throughput_target
  use_aborted_target

  def components
    [
      {
        component: ReportComponents::MachineProductivityTable,
        args: {
          expand_machine_group: expand_machine_group,
          uptime_target: uptime_target,
          utilization_target: utilization_target,
          throughput_target: throughput_target,
          aborted_target: aborted_target,
          row_targets: row_targets,
          use_planned_production_time: planned_production_time ? :niled : false
        }
      }
    ]
  end

  def row_targets
    targets = []
    @parameters[:target_ids].map do |target_id|
      target = target_from_id(target_id)
      # If we are expanding the machine groups, treat each machine from the group as a regular machine target
      next targets << target unless expand_machine_group
      next targets << target unless target.is_a? MachineGroup

      targets.concat target.machines
    end
    targets
  end

  def expand_machine_group
    @parameters[:expand_machine_group]
  end
end