module ReportComponents
    class ReportComponent

      attr_accessor :start_time, :end_time, :timeframe, :machine_ids, :use_planned_production_time, :results

      def initialize(start_time, end_time, machine_ids, timeframe, use_ppt = false)
        @start_time = start_time
        @end_time = end_time
        @timeframe = timeframe
        @machine_ids = machine_ids
        @use_planned_production_time = use_ppt
      end

      def component_id
        raise NotImplementedError
      end

      def component_type
        raise NotImplementedError
      end

      def generate(args)
        raise NotImplementedError
      end

      def start_on_the_hour?
        (start_time.seconds_since_midnight % 3600) == 0
      end

      def number_of_machines
        machine_ids.count
      end

      def build(args)
        @results = base

        report_component_start = Time.now.utc

        begin
          @results[:data], @results[:extra_data] = generate(args)
          ensure_extra_data
          @results[:meta][:status] = 'completed'
        rescue => err
          @results[:meta][:error] = err.to_s
          @results[:meta][:status] = 'failed'
        end

        report_component_end = Time.now.utc
        @results[:meta][:generate_component_details] = {
          :start => report_component_start,
          :end => report_component_end,
          :time_to_generate => (report_component_end.to_f - report_component_start.to_f).round(3)
        }

        @results
      end

      def ensure_extra_data
        return if @results[:extra_data].nil?
        @results[:extra_data] = nil if @results[:extra_data].empty?
      end

      def set_no_data(msg)
        @results[:meta][:no_data] = {}
        @results[:meta][:no_data] = {message: msg}
        {} # return empty array so this method can be chained to generate
      end

      def base
        {
          meta: {
            id: component_id,
            type: component_type,
            status: 'running',
          },
          data: {},
          extra_data: nil
        }
      end
    end
end

